[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: Re[2]: emacspeak-mew.el




切明です。

とりあえずパッチです。1.1.2.5からのdiffです。WEBにおけないので、こっちに
投げます。
--- emacspeak-mew.el.org	Thu Aug 24 02:47:28 2000
+++ emacspeak-mew.el	Thu Aug 24 02:43:14 2000
@@ -1,4 +1,4 @@
 ;;; emacspeak-mew.el --- Speech enable GNUS -- Fluent spoken access to usenet
 ;;; $Id: emacspeak-mew.el,v 1.1.2.5 2000/08/23 17:15:52 inoue Exp $
 ;;; $Author: inoue $ 
 ;;; Description:  Emacspeak extension to speech enable mew
@@ -82,9 +82,45 @@
   (emacspeak-speak-line)
 )
 
+(defadvice mew-summary-jump-top (after emacspeak pre act )
+  "speeks the message after movement"
+  (emacspeak-speak-line)
+)
+
+(defadvice mew-summary-jump-bottom (after emacspeak pre act )
+  "speeks the message after movement"
+  (emacspeak-speak-line)
+)
+
+(defadvice mew-summary-jump-message (after emacspeak pre act )
+  "speeks the message after movement"
+  (emacspeak-speak-line)
+)
+
+(defadvice mew-summary-display-review-up (after emacspeak pre act )
+  "speeks the message after movement"
+  (emacspeak-speak-line)
+)
+
+(defadvice mew-summary-display-review-down (after emacspeak pre act )
+  "speeks the message after movement"
+  (emacspeak-speak-line)
+)
+
+(defadvice mew-summary-goto-folder (after emacspeak pre act )
+  "speeks the message after movement"
+  (emacspeak-speak-line)
+)
+
 (defadvice mew-summary-delete (after emacspeak pre act )
   "tells the message is marked for delete."
-  (dtk-speak "delete")
+  (dtk-interp-queue "delete")
+  (emacspeak-speak-line)
+)
+
+(defadvice mew-summary-refile (after emacspeak pre act )
+  "tells the message is marked for refile."
+  (emacspeak-speak-line)
 )
 
 (defadvice mew-summary-undo (around emacspeak pre act )
@@ -140,10 +176,10 @@
 	(progn
 ;	  (set-buffer sum)
 ;	  (emacspeak-speak-line)
-	  (dtk-speak (format "%s of %s" num sum))
+	  (dtk-interp-queue (format "%s of %s" num sum))
 	  (dtk-speak "next")
 	  ))
-)))
+      )))
 
 (defadvice mew-summary-send (after emacspeak pre act )
   "speeks the current line after new message is opened."
@@ -1,4 +1,4 @@
-;;; emacspeak-mew.el --- Speech enable GNUS -- Fluent spoken access to usenet
+;;; emacspeak-mew.el --- Speech enable Mew -- Fluent spoken access to internet message
 ;;; $Id: emacspeak-mew.el,v 1.1.2.5 2000/08/23 17:15:52 inoue Exp $
 ;;; $Author: inoue $ 